@@ -104,10 +104,12 @@
 #include "RagTimeParser.hxx"
 #include "RagTime5Parser.hxx"
 #include "RagTime5SSParser.hxx"
+#include "StudentWritingCParser.hxx"
 #include "StyleParser.hxx"
 #include "SuperPaintParser.hxx"
 #include "TeachTxtParser.hxx"
 #include "WingzParser.hxx"
+#include "WordMakerParser.hxx"
 #include "WriteNowParser.hxx"
 #include "WriterPlsParser.hxx"
 #include "ZWrtParser.hxx"
@@ -192,17 +194,20 @@ try
   case MWAW_T_PIXELPAINT:
   case MWAW_T_POWERPOINT:
   case MWAW_T_RAGTIME:
+  case MWAW_T_STUDENTWRITING:
   case MWAW_T_STYLE:
   case MWAW_T_SUPERPAINT:
   case MWAW_T_TEACHTEXT:
   case MWAW_T_TEXEDIT:
   case MWAW_T_WINGZ:
+  case MWAW_T_WORDMAKER:
   case MWAW_T_WRITENOW:
   case MWAW_T_WRITERPLUS:
   case MWAW_T_XPRESS:
   case MWAW_T_ZWRITE:
     confidence = MWAW_C_EXCELLENT;
     break;
+
   case MWAW_T_ADOBEILLUSTRATOR:
   case MWAW_T_DBASE:
   case MWAW_T_FAMILYTREEMAKER:
@@ -220,8 +225,6 @@ try
   case MWAW_T_TRAPEZE:
   case MWAW_T_4DIMENSION:
 
-  case MWAW_T_RESERVED13:
-  case MWAW_T_RESERVED14:
   case MWAW_T_RESERVED15:
   case MWAW_T_RESERVED16:
   case MWAW_T_RESERVED17:
@@ -632,20 +635,20 @@ std::shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr
     case MWAWDocument::MWAW_T_POWERPOINT:
     case MWAWDocument::MWAW_T_RAGTIME:
     case MWAWDocument::MWAW_T_READYSETGO:
+    case MWAWDocument::MWAW_T_STUDENTWRITING:
     case MWAWDocument::MWAW_T_STYLE:
     case MWAWDocument::MWAW_T_SYMPOSIUM:
     case MWAWDocument::MWAW_T_TEACHTEXT:
     case MWAWDocument::MWAW_T_TEXEDIT:
     case MWAWDocument::MWAW_T_TRAPEZE:
     case MWAWDocument::MWAW_T_WINGZ:
+    case MWAWDocument::MWAW_T_WORDMAKER:
     case MWAWDocument::MWAW_T_WRITENOW:
     case MWAWDocument::MWAW_T_WRITERPLUS:
     case MWAWDocument::MWAW_T_XPRESS:
     case MWAWDocument::MWAW_T_ZWRITE:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED13:
-    case MWAWDocument::MWAW_T_RESERVED14:
     case MWAWDocument::MWAW_T_RESERVED15:
     case MWAWDocument::MWAW_T_RESERVED16:
     case MWAWDocument::MWAW_T_RESERVED17:
@@ -746,6 +749,7 @@ std::shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInpu
     case MWAWDocument::MWAW_T_PIXELPAINT:
     case MWAWDocument::MWAW_T_RAGTIME:
     case MWAWDocument::MWAW_T_READYSETGO:
+    case MWAWDocument::MWAW_T_STUDENTWRITING:
     case MWAWDocument::MWAW_T_STYLE:
     case MWAWDocument::MWAW_T_SUPERPAINT:
     case MWAWDocument::MWAW_T_SYMPOSIUM:
@@ -753,14 +757,13 @@ std::shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInpu
     case MWAWDocument::MWAW_T_TEXEDIT:
     case MWAWDocument::MWAW_T_TRAPEZE:
     case MWAWDocument::MWAW_T_WINGZ:
+    case MWAWDocument::MWAW_T_WORDMAKER:
     case MWAWDocument::MWAW_T_WRITENOW:
     case MWAWDocument::MWAW_T_WRITERPLUS:
     case MWAWDocument::MWAW_T_XPRESS:
     case MWAWDocument::MWAW_T_ZWRITE:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED13:
-    case MWAWDocument::MWAW_T_RESERVED14:
     case MWAWDocument::MWAW_T_RESERVED15:
     case MWAWDocument::MWAW_T_RESERVED16:
     case MWAWDocument::MWAW_T_RESERVED17:
@@ -885,19 +888,19 @@ std::shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputS
     case MWAWDocument::MWAW_T_POWERPOINT:
     case MWAWDocument::MWAW_T_PIXELPAINT:
     case MWAWDocument::MWAW_T_READYSETGO:
+    case MWAWDocument::MWAW_T_STUDENTWRITING:
     case MWAWDocument::MWAW_T_STYLE:
     case MWAWDocument::MWAW_T_SUPERPAINT:
     case MWAWDocument::MWAW_T_SYMPOSIUM:
     case MWAWDocument::MWAW_T_TEACHTEXT:
     case MWAWDocument::MWAW_T_TEXEDIT:
+    case MWAWDocument::MWAW_T_WORDMAKER:
     case MWAWDocument::MWAW_T_WRITENOW:
     case MWAWDocument::MWAW_T_WRITERPLUS:
     case MWAWDocument::MWAW_T_XPRESS:
     case MWAWDocument::MWAW_T_ZWRITE:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED13:
-    case MWAWDocument::MWAW_T_RESERVED14:
     case MWAWDocument::MWAW_T_RESERVED15:
     case MWAWDocument::MWAW_T_RESERVED16:
     case MWAWDocument::MWAW_T_RESERVED17:
@@ -1013,6 +1016,9 @@ std::shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &inpu
       else
         parser.reset(new RagTime5Parser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_STUDENTWRITING:
+      parser.reset(new StudentWritingCParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_STYLE:
       parser.reset(new StyleParser(input, rsrcParser, header));
       break;
@@ -1020,6 +1026,9 @@ std::shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &inpu
     case MWAWDocument::MWAW_T_TEXEDIT:
       parser.reset(new TeachTxtParser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_WORDMAKER:
+      parser.reset(new WordMakerParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_WRITENOW:
       parser.reset(new WriteNowParser(input, rsrcParser, header));
       break;
@@ -1066,8 +1075,6 @@ std::shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &inpu
     case MWAWDocument::MWAW_T_XPRESS:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED13:
-    case MWAWDocument::MWAW_T_RESERVED14:
     case MWAWDocument::MWAW_T_RESERVED15:
     case MWAWDocument::MWAW_T_RESERVED16:
     case MWAWDocument::MWAW_T_RESERVED17:
