@@ -157,54 +157,62 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
         return res;
       }
     }
-    else if (creator=="DAD2") {
-      if (type=="drw2") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 2, MWAWDocument::MWAW_K_DRAW));
-        return res;
+    else if (creator.substr(0,3)=="DAD") {
+      if (creator=="DAD2") {
+        if (type=="drw2") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 2, MWAWDocument::MWAW_K_DRAW));
+          return res;
+        }
       }
-    }
-    else if (creator=="DAD5") {
-      if (type=="drw2") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 2, MWAWDocument::MWAW_K_DRAW));
-        return res;
+      else if (creator=="DAD5") {
+        if (type=="drw2") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 2, MWAWDocument::MWAW_K_DRAW));
+          return res;
+        }
+        if (type=="drw5" || type=="drwt") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 5, MWAWDocument::MWAW_K_DRAW));
+          return res;
+        }
+        if (type=="VINF") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 5, MWAWDocument::MWAW_K_PAINT));
+          return res;
+        }
       }
-      if (type=="drw5" || type=="drwt") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 5, MWAWDocument::MWAW_K_DRAW));
-        return res;
+      else if (creator=="DAD6") {
+        if (type=="drw6" || type=="drwt") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 6, MWAWDocument::MWAW_K_DRAW));
+          return res;
+        }
+        if (type=="VINF") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 6, MWAWDocument::MWAW_K_PAINT));
+          return res;
+        }
       }
-      if (type=="VINF") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 5, MWAWDocument::MWAW_K_PAINT));
-        return res;
+      else if (creator=="DAD7") {
+        if (type=="drw7" || type=="drwt") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 7, MWAWDocument::MWAW_K_DRAW));
+          return res;
+        }
+        if (type=="VINF") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 7, MWAWDocument::MWAW_K_PAINT));
+          return res;
+        }
       }
-    }
-    else if (creator=="DAD6") {
-      if (type=="drw6" || type=="drwt") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 6, MWAWDocument::MWAW_K_DRAW));
-        return res;
+      else if (creator=="DAD8") {
+        if (type=="drw8" || type=="drwt") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 8, MWAWDocument::MWAW_K_DRAW));
+          return res;
+        }
+        if (type=="VINF") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 8, MWAWDocument::MWAW_K_PAINT));
+          return res;
+        }
       }
-      if (type=="VINF") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 6, MWAWDocument::MWAW_K_PAINT));
-        return res;
-      }
-    }
-    else if (creator=="DAD7") {
-      if (type=="drw7" || type=="drwt") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 7, MWAWDocument::MWAW_K_DRAW));
-        return res;
-      }
-      if (type=="VINF") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 7, MWAWDocument::MWAW_K_PAINT));
-        return res;
-      }
-    }
-    else if (creator=="DAD8") {
-      if (type=="drw8" || type=="drwt") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 8, MWAWDocument::MWAW_K_DRAW));
-        return res;
-      }
-      if (type=="VINF") {
-        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 8, MWAWDocument::MWAW_K_PAINT));
-        return res;
+      else if (creator=="DAD9" || creator=="DADX") {
+        if (type=="drwX" || type=="drwt") {
+          res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 9, MWAWDocument::MWAW_K_DRAW));
+          return res;
+        }
       }
     }
     else if (creator=="Dc@P" || creator=="Dk@P") {
@@ -537,12 +545,24 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
         return res;
       }
     }
+    else if (creator=="SWCM") {
+      if (type=="JRNL" || type=="LTTR" || type=="NWSL" || type=="RPRT" || type=="SIGN") {
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_STUDENTWRITING, 1));
+        return res;
+      }
+    }
     else if (creator=="TBB5") {
       if (type=="TEXT" || type=="ttro") {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_TEXEDIT, 1));
         return res;
       }
     }
+    else if (creator=="WMkr") {
+      if (type=="Word" || type=="WSta") {
+        res.push_back(MWAWHeader(MWAWDocument::MWAW_T_WORDMAKER, 1));
+        return res;
+      }
+    }
     else if (creator=="WNGZ") {
       if (type=="WZSS") {
         res.push_back(MWAWHeader(MWAWDocument::MWAW_T_WINGZ, 1, MWAWDocument::MWAW_K_SPREADSHEET));
@@ -768,6 +788,10 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
       // can also be a classic apple pict, so let's continue
     }
   }
+  if (val[0]==0x1a54 && val[1]==0x4c43 && (val[2]&0xfeff)==0x246 && val[3]==0x4600) {
+    MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a Student Writing Center file\n"));
+    res.push_back(MWAWHeader(MWAWDocument::MWAW_T_STUDENTWRITING, 1));
+  }
   if (val[0]==0x5354 && val[1]==0x4154 && (val[2]==0 || val[2]==0x4432)) {
     MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a MacDraw II template file\n"));
     res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MACDRAWPRO, 0, MWAWDocument::MWAW_K_DRAW));
@@ -823,11 +847,24 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
       input->setReadInverted(false);
     }
   }
-  if (val[0]==0 && val[1]==1 && val[2]==0x4441 && val[3]==0x4435 && val[4]==0x5052) {
-    MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a potential Canvas 5/6 image file\n"));
-    res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 5, MWAWDocument::MWAW_K_PAINT));
+  if (val[0]==0 && val[1]==0 && val[2]==0 && val[3]==0 && val[4]==0) {
+    input->seek(10, librevenge::RVNG_SEEK_SET);
+    int v=int(input->readULong(2));
+    if ((v==0x100 && input->readULong(2)==0x8000) || // windows
+        (v==0x200 && input->readULong(2)==0x80)) { // mac
+      MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a potential Canvas 9-11 file\n"));
+      res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, 9, MWAWDocument::MWAW_K_DRAW));
+    }
+  }
+  if (val[0]==0 && (val[1]==1||val[1]==2) && val[2]==0x4441 && val[3]==0x4435 && val[4]==0x5052) {
+    if (val[1]==1) {
+      MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a potential Canvas 5-8 image file\n"));
+    }
+    else {
+      MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a potential Canvas 9-10 image file\n"));
+    }
+    res.push_back(MWAWHeader(MWAWDocument::MWAW_T_CANVAS, val[1]==1 ? 5 : 9, MWAWDocument::MWAW_K_PAINT));
   }
-
   if (val[0]==2 && val[1]==0 && val[2]==2 && val[3]==0x262 && val[4]==0x262) {
     MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a MacDraft file\n"));
     res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MACDRAFT, 1, MWAWDocument::MWAW_K_DRAW));
@@ -986,6 +1023,10 @@ std::vector<MWAWHeader> MWAWHeader::constructHeader
     MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a MacWritePro file\n"));
     res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MACWRITEPRO, 1));
   }
+  if (val[0]==0x464f && val[1]==0x524d) {
+    MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a WordMaker file\n"));
+    res.push_back(MWAWHeader(MWAWDocument::MWAW_T_WORDMAKER, 1));
+  }
   if (val[0] == 0x7704) {
     MWAW_DEBUG_MSG(("MWAWHeader::constructHeader: find a MindWrite file 2.1\n"));
     res.push_back(MWAWHeader(MWAWDocument::MWAW_T_MINDWRITE, 2));
