@@ -297,24 +297,34 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="CRDW") {
     checkFInfoType("CKDT","CricketDraw") || checkFInfoType("CricketDraw");
   }
-  else if (m_fInfoCreator=="DAD2") {
-    checkFInfoType("drw2","Canvas 2-3") || checkFInfoType("Canvas 2-3");
-  }
-  else if (m_fInfoCreator=="DAD5") {
-    checkFInfoType("drw5","Canvas 5") || checkFInfoType("drwt","Canvas 5[template]") ||
-    checkFInfoType("VINF","Canvas 5[image]") || checkFInfoType("Canvas 5");
-  }
-  else if (m_fInfoCreator=="DAD6") {
-    checkFInfoType("drw6","Canvas 6") || checkFInfoType("drwt","Canvas 6[template]") ||
-    checkFInfoType("VINF","Canvas 6[image]") || checkFInfoType("Canvas 6");
-  }
-  else if (m_fInfoCreator=="DAD7") {
-    checkFInfoType("drw7","Canvas 7") || checkFInfoType("drwt","Canvas 7[template]") ||
-    checkFInfoType("VINF","Canvas 7[image]") || checkFInfoType("Canvas 7");
-  }
-  else if (m_fInfoCreator=="DAD8") {
-    checkFInfoType("drw8","Canvas 8") || checkFInfoType("drwt","Canvas 8[template]") ||
-    checkFInfoType("VINF","Canvas 8[image]") || checkFInfoType("Canvas 8");
+  else if (m_fInfoCreator.substr(0,3)=="DAD") {
+    if (m_fInfoCreator=="DAD2") {
+      checkFInfoType("drw2","Canvas 2-3") || checkFInfoType("Canvas 2-3");
+    }
+    else if (m_fInfoCreator=="DAD5") {
+      checkFInfoType("drw5","Canvas 5") || checkFInfoType("drwt","Canvas 5[template]") ||
+      checkFInfoType("VINF","Canvas 5[image]") || checkFInfoType("Canvas 5");
+    }
+    else if (m_fInfoCreator=="DAD6") {
+      checkFInfoType("drw6","Canvas 6") || checkFInfoType("drwt","Canvas 6[template]") ||
+      checkFInfoType("VINF","Canvas 6[image]") || checkFInfoType("Canvas 6");
+    }
+    else if (m_fInfoCreator=="DAD7") {
+      checkFInfoType("drw7","Canvas 7") || checkFInfoType("drwt","Canvas 7[template]") ||
+      checkFInfoType("VINF","Canvas 7[image]") || checkFInfoType("Canvas 7");
+    }
+    else if (m_fInfoCreator=="DAD8") {
+      checkFInfoType("drw8","Canvas 8") || checkFInfoType("drwt","Canvas 8[template]") ||
+      checkFInfoType("VINF","Canvas 8[image]") || checkFInfoType("Canvas 8");
+    }
+    else if (m_fInfoCreator=="DAD9") {
+      checkFInfoType("drwX","Canvas 9") || checkFInfoType("drwt","Canvas 9[template]") ||
+      checkFInfoType("Canvas 9");
+    }
+    else if (m_fInfoCreator=="DADX") {
+      checkFInfoType("drwX","Canvas X") || checkFInfoType("drwt","Canvas X[template]") ||
+      checkFInfoType("Canvas X");
+    }
   }
   else if (m_fInfoCreator=="DkmR") {
     checkFInfoType("TEXT","Basic text(created by DOCMaker)") || checkFInfoType("DOCMaker");
@@ -540,6 +550,11 @@ bool File::readFileInformation()
     std::string type1=std::string("SW/")+char(0xa9);
     checkFInfoType(type1.c_str(), "StarWriter 3.0") ||  checkFInfoType("StarWriter 3.0");
   }
+  else if (m_fInfoCreator=="SWCM") {
+    checkFInfoType("JRNL","Student Writing Center[journal]") || checkFInfoType("LTTR","Student Writing Center[letter]") ||
+    checkFInfoType("RPRT","Student Writing Center[report]") || checkFInfoType("SIGN","Student Writing Center[sign]") ||
+    checkFInfoType("Student Writing Center");
+  }
   else if (m_fInfoCreator=="TBB5") {
     checkFInfoType("TEXT","Tex-Edit") || checkFInfoType("ttro","Tex-Edit[readOnly]") ||
     checkFInfoType("Tex-Edit");
@@ -547,6 +562,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="WILD") {
     checkFInfoType("STAK", "HyperCard") || checkFInfoType("HyperCard");
   }
+  else if (m_fInfoCreator=="WMkr") {
+    checkFInfoType("Word","WordMaker") || checkFInfoType("WSta","WordMaker[template]") || checkFInfoType("WordMaker");
+  }
   else if (m_fInfoCreator=="WNGZ") {
     checkFInfoType("WZSS","Wingz[spreadsheet]") || checkFInfoType("WZSC","Wingz[script]") ||
     checkFInfoType("Wingz");
@@ -793,6 +811,10 @@ bool File::readDataInformation()
     m_dataResult.push_back("PNG");
     return true;
   }
+  if (val[0]==0x1a54 && val[1]==0x4c43 && (val[2]&0xfeff)==0x246 && val[3]==0x4600) {
+    m_dataResult.push_back("Student Writing Center");
+    return true;
+  }
   if (val[3]==6 && val[4]==3 && input.length()>30) {
     input.seek(10, InputStream::SK_SET);
     if (val[0]==0x4d44 && val[1]==0x4443 && val[2]==0x3230) {
@@ -804,8 +826,11 @@ bool File::readDataInformation()
       return true;
     }
   }
-  if (val[0]==0 && val[1]==1 && val[2]==0x4441 && val[3]==0x4435 && val[4]==0x5052) {
-    m_dataResult.push_back("Canvas Image 5-7");
+  if (val[0]==0 && (val[1]==1||val[1]==2) && val[2]==0x4441 && val[3]==0x4435 && val[4]==0x5052) {
+    if (val[1]==1)
+      m_dataResult.push_back("Canvas Image 5-8");
+    else
+      m_dataResult.push_back("Canvas Image 9");
     return true;
   }
   if (val[0]==0x200 && val[1]==0x80) {
@@ -844,6 +869,18 @@ bool File::readDataInformation()
       }
     }
   }
+  if (val[0]==0 && val[1]==0 && val[2]==0 && val[3]==0 && val[4]==0) {
+    input.seek(10, InputStream::SK_SET);
+    unsigned endian=unsigned(input.readU16());
+    if (endian==0x100 && input.readU16()==0x8000) {
+      m_dataResult.push_back("Canvas 9-11[windows]");
+      return true;
+    }
+    if (endian==0x200 && input.readU16()==0x80) {
+      m_dataResult.push_back("Canvas 9-10[mac]");
+      return true;
+    }
+  }
   if (val[0]==0xffd8 &&
       ((val[1]==0xffe0 && val[3]==0x4a46 && val[4] == 0x4946) ||
        (val[1]==0xffe1 && val[3]==0x4578 && val[4] == 0x6966) ||
@@ -953,6 +990,8 @@ bool File::readDataInformation()
       break;
     }
   }
+  if (val[0]==0x464f && val[1]==0x524d)
+    m_dataResult.push_back("WordMaker");
   if (val[0]==0 && input.length() > 30) {
     input.seek(16, InputStream::SK_SET);
     if (input.readU16()==0x688f && input.readU16()==0x688f) {
